==> progamification-1.5.0.tar.gz: lib/src/services/auth.service.dart <==
import 'package:dio/dio.dart';
import 'package:progamification/src/constants/service_urls.dart';
import 'package:progamification/src/services/storage.service.dart';
import 'package:progamification/src/utilities/http_client.dart';
import 'package:jwt_decoder/jwt_decoder.dart';
import 'package:shared_preferences/shared_preferences.dart';

class GamificationAuthService {
  static Future<dynamic> init(String? clientId, String? clientSecret) async {
    Dio httpClient = getHttpClient();
    Response response;
    try {
      Map<String, dynamic> bodyMap = {
        'clientId': clientId,
        'clientSecret': clientSecret
      };
      response = await httpClient.post(ServiceUrls.getAuthToken,
          data: bodyMap,
          options: Options(
            headers: bodyMap,
          ));
      if (response.statusCode == 200) {
        dynamic data = response.data;
        String accessToken = data['data']['access_token'];
        await GamificationStorageService.setString(
            'gamificationAccessToken', accessToken);
      }
    } catch (exception) {
      throw Exception(exception);
    }
    return response;
  }

  static Future<bool> checkAccess() async {
    SharedPreferences preferences = await SharedPreferences.getInstance();
    String? accessToken = preferences.getString('gamificationAccessToken');
    if (accessToken == null) {
      return false;
    }
    bool isExpired = JwtDecoder.isExpired(accessToken);
    if (isExpired) {
      return false;
    }
    return true;
  }

  static Future<dynamic> getRefreshedToken(
      String? clientId, String? clientSecret) async {
    Dio httpClient = getHttpClient();
    Map<String, dynamic> bodyMap = {
      'clientId': clientId,
      'clientSecret': clientSecret
    };
    Response response;
    try {
      response = await httpClient.post(
        ServiceUrls.getAuthToken,
        data: bodyMap,
      );
      if (response.statusCode == 200) {
        dynamic data = response.data;
        String accessToken = data['data']['access_token'];
        await GamificationStorageService.setString(
            'gamificationAccessToken', accessToken);
      }
    } catch (exception) {
      throw Exception(exception);
    }
    return response;
  }
}

==> progamification-1.7.0.tar.gz: lib/src/services/auth.service.dart <==
import 'package:dio/dio.dart';
import 'package:progamification/src/constants/service_urls.dart';
import 'package:progamification/src/environments/env.dart';
import 'package:progamification/src/services/storage.service.dart';
import 'package:progamification/src/utilities/http_client.dart';
import 'package:jwt_decoder/jwt_decoder.dart';
import 'package:shared_preferences/shared_preferences.dart';

class GamificationAuthService {
  static Future<dynamic> init(String? clientId, String? clientSecret) async {
    Dio httpClient = getHttpClient(baseUrl);
    Response response;
    try {
      Map<String, dynamic> bodyMap = {
        'clientId': clientId,
        'clientSecret': clientSecret
      };
      response = await httpClient.post(ServiceUrls.getAuthToken,
          data: bodyMap,
          options: Options(
            headers: bodyMap,
          ));
      if (response.statusCode == 200) {
        dynamic data = response.data;
        String accessToken = data['data']['access_token'];
        await GamificationStorageService.setString(
            'gamificationAccessToken', accessToken);
      }
    } catch (exception) {
      throw Exception(exception);
    }
    return response;
  }

  static Future<bool> checkAccess() async {
    SharedPreferences preferences = await SharedPreferences.getInstance();
    String? accessToken = preferences.getString('gamificationAccessToken');
    if (accessToken == null) {
      return false;
    }
    bool isExpired = JwtDecoder.isExpired(accessToken);
    if (isExpired) {
      return false;
    }
    return true;
  }


}
